@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2014-2016, Lazaros Koromilas <lostd@2f30.org>
  * Copyright (C) 2014-2016, Dimitris Papastamos <sin@2f30.org>
- * Copyright (C) 2016-2023, Arun Prakash Jana <engineerarun@gmail.com>
+ * Copyright (C) 2016-2024, Arun Prakash Jana <engineerarun@gmail.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -96,7 +96,8 @@ enum action {
 	SEL_CP,
 	SEL_MV,
 	SEL_CPMVAS,
-	SEL_RM,
+	SEL_TRASH,
+	SEL_RM_ONLY,
 	SEL_OPENWITH,
 	SEL_NEW,
 	SEL_RENAME,
@@ -239,8 +240,9 @@ static struct key bindings[] = {
 	{ 'w',            SEL_CPMVAS },
 	{ CONTROL('W'),   SEL_CPMVAS },
 	/* Delete from selection buffer */
-	{ 'x',            SEL_RM },
-	{ CONTROL('X'),   SEL_RM },
+	{ 'x',            SEL_TRASH },
+	{ CONTROL('X'),   SEL_TRASH },
+	{ 'X',            SEL_RM_ONLY },
 	/* Open in a custom application */
 	{ 'o',            SEL_OPENWITH },
 	{ CONTROL('O'),   SEL_OPENWITH },
